
--
-- Polynom
-- Copyright 2024 Code Siren, LLC
-- SQLite Update Script
-- September 12, 2024
-- Version 1.2.0
--


--
-- Note
--
DROP TABLE IF EXISTS note;
CREATE TABLE IF NOT EXISTS note
(
	-- Primary Keys
	id INTEGER PRIMARY KEY AUTOINCREMENT,

	-- Foreign Keys
	owner_id INTEGER NOT NULL,
	social_id INTEGER,

	-- Fields
	category TEXT,
	cipher_text BLOB,
	color INTEGER,
	created INTEGER NOT NULL,
	description TEXT,
	glyph TEXT,
	image_hash BLOB,
	image_height INTEGER,
	image_size INTEGER,
	image_width INTEGER,
	modified INTEGER,
	name TEXT,
	nonce INTEGER,
	rank INTEGER,
	signature BLOB,
	text TEXT,

	-- Constraints
	FOREIGN KEY(owner_id) REFERENCES user(id) ON DELETE CASCADE,
	UNIQUE(nonce, owner_id)
);

-- Indices
DROP INDEX IF EXISTS idx_note_owner_id;
CREATE INDEX idx_note_owner_id ON note(owner_id);

DROP INDEX IF EXISTS idx_note_nonce;
CREATE INDEX idx_note_nonce ON note(nonce);


--
-- Note File
--
DROP TABLE IF EXISTS note_file;
CREATE TABLE IF NOT EXISTS note_file
(
	-- Primary Keys
	id INTEGER PRIMARY KEY AUTOINCREMENT,

	-- Foreign Keys
	note_id INTEGER NOT NULL,
	owner_id INTEGER NOT NULL,
	social_id INTEGER,

	-- Fields
	animation BOOLEAN,
	cipher_text BLOB,
	created INTEGER NOT NULL,
	hash BLOB,
	height INTEGER,
	image_hash BLOB,
	image_height INTEGER,
	image_size INTEGER,
	image_width INTEGER,
	modified INTEGER,
	name TEXT NOT NULL collate nocase,
	nonce INTEGER,
	size INTEGER,
	width INTEGER,

	-- Constraints
	FOREIGN KEY(note_id) REFERENCES note(id) ON DELETE CASCADE,
	FOREIGN KEY(owner_id) REFERENCES user(id) ON DELETE CASCADE,
	UNIQUE(nonce, owner_id, note_id)
);

-- Indices
DROP INDEX IF EXISTS idx_note_file_owner_id;
CREATE INDEX idx_note_file_owner_id ON note_file(owner_id);

DROP INDEX IF EXISTS idx_note_file_note_id;
CREATE INDEX idx_note_file_note_id ON note_file(note_id);

DROP INDEX IF EXISTS idx_note_file_nonce;
CREATE INDEX idx_note_file_nonce ON note_file(nonce);


--
-- Note Text Mention
--
DROP TABLE IF EXISTS note_text_mention;


--
-- Note Text File
--
DROP TABLE IF EXISTS note_text_file;


--
-- Note Text
--
DROP TABLE IF EXISTS note_text;


--
-- Server Text
--
DROP TABLE IF EXISTS server_text;
CREATE TABLE IF NOT EXISTS server_text
(
	-- Primary Keys
	id INTEGER PRIMARY KEY AUTOINCREMENT,

	-- Foreign Keys
	owner_id INTEGER NOT NULL,
	user_id INTEGER,

	-- Fields
	cipher_key BLOB,
	cipher_text BLOB,
	created INTEGER NOT NULL,
	modified INTEGER,
	nonce INTEGER,
	signature BLOB,
	text TEXT,

	-- Constraints
	FOREIGN KEY(owner_id) REFERENCES user(id) ON DELETE CASCADE,
	FOREIGN KEY(user_id) REFERENCES user(id) ON DELETE CASCADE,
	UNIQUE(nonce, owner_id)
);

-- Indices
DROP INDEX IF EXISTS idx_server_text_owner_id;
CREATE INDEX idx_server_text_owner_id ON server_text(owner_id);

DROP INDEX IF EXISTS idx_server_text_user_id;
CREATE INDEX idx_server_text_user_id ON server_text(user_id);

DROP INDEX IF EXISTS idx_server_text_created;
CREATE INDEX idx_server_text_created ON server_text(created);

DROP INDEX IF EXISTS idx_server_text_nonce;
CREATE INDEX idx_server_text_nonce ON server_text(nonce);


--
-- Server Text File
--
DROP TABLE IF EXISTS server_text_file;
CREATE TABLE IF NOT EXISTS server_text_file
(
	-- Primary Keys
	id INTEGER PRIMARY KEY AUTOINCREMENT,

	-- Foreign Keys
	owner_id INTEGER NOT NULL,
	text_id INTEGER NOT NULL,
	user_id INTEGER,

	-- Fields
	animation BOOLEAN,
	cipher_key BLOB,
	created INTEGER NOT NULL,
	hash BLOB NOT NULL,
	height INTEGER,
	image_hash BLOB,
	image_height INTEGER,
	image_size INTEGER,
	image_width INTEGER,
	modified INTEGER,
	name TEXT NOT NULL,	-- Encrypted
	nonce INTEGER,
	size INTEGER,
	width INTEGER,

	-- Constraints
	FOREIGN KEY(owner_id) REFERENCES user(id) ON DELETE CASCADE,
	FOREIGN KEY(text_id) REFERENCES server_text(id) ON DELETE CASCADE,
	FOREIGN KEY(user_id) REFERENCES user(id) ON DELETE CASCADE
);

-- Indices
DROP INDEX IF EXISTS idx_server_text_file_owner_id;
CREATE INDEX idx_server_text_file_owner_id ON server_text_file(owner_id);

DROP INDEX IF EXISTS idx_server_text_file_text_id;
CREATE INDEX idx_server_text_file_text_id ON server_text_file(text_id);

DROP INDEX IF EXISTS idx_server_text_file_user_id;
CREATE INDEX idx_server_text_file_user_id ON server_text_file(user_id);

DROP INDEX IF EXISTS idx_server_text_file_created;
CREATE INDEX idx_server_text_file_created ON server_text_file(created);

DROP INDEX IF EXISTS idx_server_text_file_hash;
CREATE INDEX idx_server_text_file_hash ON server_text_file(hash);

DROP INDEX IF EXISTS idx_server_text_file_name;
CREATE INDEX idx_server_text_file_name ON server_text_file(name collate nocase);

DROP INDEX IF EXISTS idx_server_text_file_nonce;
CREATE INDEX idx_server_text_file_nonce ON server_text_file(nonce);


--
-- Server Text Mention
--
DROP TABLE IF EXISTS server_text_mention;
CREATE TABLE IF NOT EXISTS server_text_mention
(
	-- Primary Keys
	id INTEGER PRIMARY KEY AUTOINCREMENT,

	-- Foreign Keys
	owner_id INTEGER NOT NULL,
	text_id INTEGER NOT NULL,
	user_id INTEGER NOT NULL,

	-- Fields
	position INTEGER NOT NULL,

	-- Constraints
	FOREIGN KEY(owner_id) REFERENCES user(id) ON DELETE CASCADE,
	FOREIGN KEY(text_id) REFERENCES server_text(id) ON DELETE CASCADE,
	FOREIGN KEY(user_id) REFERENCES user(id) ON DELETE CASCADE
);

-- Indices
DROP INDEX IF EXISTS idx_server_text_mention_owner_id;
CREATE INDEX idx_server_text_mention_owner_id ON server_text_mention(owner_id);

DROP INDEX IF EXISTS idx_server_text_mention_text_id;
CREATE INDEX idx_server_text_mention_text_id ON server_text_mention(text_id);

DROP INDEX IF EXISTS idx_server_text_mention_user_id;
CREATE INDEX idx_server_text_mention_user_id ON server_text_mention(user_id);
